@@ -42,9 +42,6 @@ class SentryHandler(logging.Handler, object):
                 ))
         elif 'client' in kwargs:
             self.client = kwargs['client']
-        elif len(args) == 2 and not kwargs:
-            servers, key = args
-            self.client = client(servers=servers, key=key)
         else:
             self.client = client(*args, **kwargs)
 
